@@ -5,12 +5,11 @@
 # file that should have been included as part of this package.
 
 class convertido(object):
-    def __init__(self,rea,incertidumbre,r_fc,serie_rea_pro,serie_rea_his,serie_incertidumbre):
+    def __init__(self,rea,incertidumbre,r_fc,serie_rea_pro,serie_rea_his):
         self.rea=rea
         self.incertidumbre=incertidumbre
         self.serie_rea_historico=serie_rea_his
         self.serie_rea_proyectado=serie_rea_pro
-        self.serie_incertidumbre=serie_incertidumbre
         self.pesos_por_modelo=r_fc
     def plot(self):
         print('todavia no hay ploteos disponibles')
